cosinnus.views.mixins package
=============================

Submodules
----------

cosinnus.views.mixins.ajax module
---------------------------------

.. automodule:: cosinnus.views.mixins.ajax
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.views.mixins.group module
----------------------------------

.. automodule:: cosinnus.views.mixins.group
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.views.mixins.tagged module
-----------------------------------

.. automodule:: cosinnus.views.mixins.tagged
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.views.mixins.user module
---------------------------------

.. automodule:: cosinnus.views.mixins.user
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.views.mixins
    :members:
    :undoc-members:
    :show-inheritance:
